package loan.origination.routing;

import loan.origination.*;
import loan.origination.routing.service.RoutingClient;
import loan.origination.routing.service.RoutingRequest;
import loan.origination.routing.service.RoutingResponse;

public class RoutingLauncherLambda {
	
	String endPointURL = "https://1d9i2qxbc3.execute-api.us-east-1.amazonaws.com/test/routing"; 
	RoutingClient client;

	public RoutingLauncherLambda() throws Exception {
		client = new RoutingClient(endPointURL);
	}
	
	public RoutingResponse execute(Application application, Applicant applicant, RequestedProduct requestedProduct, BureauData bureauData) throws Exception {
		try {
			RoutingRequest request = new RoutingRequest();
	        request.setApplicant(applicant);
	        request.setApplication(application);
	        request.setRequestedProduct(requestedProduct);
	        request.setBureauData(bureauData);
	        RoutingResponse response = client.execute(request);
	        String routing = response.getApplication().getRouting();
	        application.setRouting(routing);
	        System.out.println("Routing: " + application.getRouting());
	        return response;
		} catch (Exception e) {
			System.out.println("ERROR executing Lambda: " + endPointURL);
			throw e;
		}
	}
    
    public static void main(String[] args) throws Exception {
        
    	RoutingLauncherLambda launcher = new RoutingLauncherLambda();
        
        Applicant[] applicants = applicantsArray.get();
        Application[] applications = applicationsArray.get();
        RequestedProduct[] requestedProducts = requestedProductsArray.get();
        BureauData[] bureauData = bureauDataArray.get();
        
        for (int i = 0; i< applicants.length; i++) {
            System.out.println("\nTest " + i + ": " + applications[i]);
            long startTime = System.currentTimeMillis();
            RoutingResponse response = launcher.execute(applications[i],applicants[i],requestedProducts[i],bureauData[i]);
            long endTime = System.currentTimeMillis();
            System.out.println("Elapsed time: " + (endTime - startTime +1) + " ms");
        }
    }
 
}
